import boto3
import uuid
from navio.aws.services._session import AWSSession


class AWSACM(AWSSession):

    def __init__(self, **kwargs):
        super(
            self.__class__,
            self
        ).__init__(kwargs['profile_name'])

    def request_via_dns(self, **kwargs):
        if 'domain_name' not in kwargs:
            raise Exception('Argument missing: domain_name')

        if 'alternative_names' not in kwargs:
            raise Exception('Argument missing: alternative_names')

        client = self.client('acm')

        resp = client.request_certificate(
            DomainName=kwargs.get('domain_name'),
            SubjectAlternativeNames=kwargs.get('alternative_names'),
            ValidationMethod='DNS',
            IdempotencyToken=uuid.uuid4()
        )

        return resp

    def get_dns_validation_options(self, **kwargs):
        if 'certificate_arn' not in kwargs:
            raise Exception('Argument missing: certificate_arn')

        client = self.client('acm')

        resp = client.describe_certificate(
            CertificateArn=certificate_arn
        )

        return resp.get('Certificate') \
                   .get('DomainValidationOptions')[0] \
                   .get('ResourceRecord')



import boto3
import botocore
import os
import uuid
import fnmatch
import re
import sh
import mimetypes
import copy
import uuid
from vulcan.aws.services._session import AWSSession
from concurrent import futures


class AWSCloudFront(AWSSession):

    def __init__(self, **kwargs):
        super(self.__class__, self).__init__(kwargs['profile_name'])
        self.distribution_id = kwargs.get('distribution_id')

    def invalidate(self, **kwargs):
        cloudfront = self.client('cloudfront')
        resp = cloudfront.create_invalidation(
            DistributionId=self.distribution_id,
            InvalidationBatch={
                'CallerReference': uuid.uuid4().hex,
                'Paths': {
                    'Quantity': len(kwargs.get('files')),
                    'Items': kwargs.get('files')
                }
            }
        )
